@@ -1,5 +1,5 @@
 # mamgal - a program for creating static image galleries
-# Copyright 2007-2010 Marcin Owsiany <marcin@owsiany.pl>
+# Copyright 2007-2012 Marcin Owsiany <marcin@owsiany.pl>
 # See the README file for license information
 # The directory encapsulating class
 package App::MaMGal::Entry::Dir;
@@ -173,7 +173,7 @@ sub _write_montage
 		my $img = Image::Magick->new;
 		my $rr;
 		$rr = $img->Read($_->tile_path) and App::MaMGal::SystemException->throw(message => '%s: %s', objects => [$_->tile_path, $rr]);
-		$img } @images[0..($montage_count-1)];
+		$img->[0] or $img } @images[0..($montage_count-1)];
 
 	my $side = $self->_side_length($montage_count);
 
